@@ -1,6 +1,7 @@
 import asyncio
 import collections
 import logging
+import pprint
 import random
 import time
 from functools import wraps
@@ -133,8 +134,14 @@ class QCticJob(BaseJob):
             raise JobError(error)
 
         result_dict = self._remote_job.get("result", None)
+        result = Result.from_dict(result_dict) if result_dict else None
 
-        return Result.from_dict(result_dict) if result_dict else None
+        if result and not result.success:
+            _logger.warning(
+                "Some experiments failed:\n%s",
+                pprint.pformat([item.status for item in result.results]))
+
+        return result
 
     def _status(self):
         return self._remote_job.get("status", None)
