@@ -68,6 +68,14 @@ class JobSchema(Schema):
         format="iso",
         default_timezone=datetime.timezone.utc)
 
+    date_execute_start = fields.AwareDateTime(
+        format="iso",
+        default_timezone=datetime.timezone.utc)
+
+    date_execute_end = fields.AwareDateTime(
+        format="iso",
+        default_timezone=datetime.timezone.utc)
+
     qobj = fields.Mapping(
         required=True,
         validate=_qiskit_model_validator(Qobj))
@@ -78,7 +86,8 @@ class JobSchema(Schema):
 
     result = fields.Mapping(
         required=False,
-        validate=_qiskit_model_validator(Result))
+        validate=_qiskit_model_validator(Result),
+        allow_none=True)
 
     error = fields.Str()
     run_params = fields.Mapping()
